@@ -4,7 +4,7 @@ import unittest
 
 import torch
 
-from torch_ppr import api
+from torch_ppr import page_rank, personalized_page_rank, utils
 
 
 class APITest(unittest.TestCase):
@@ -23,14 +23,23 @@ class APITest(unittest.TestCase):
             ],
             dim=-1,
         )
+        self.adj = utils.prepare_page_rank_adjacency(edge_index=self.edge_index)
 
-    def test_page_rank(self):
+    def test_page_rank_edge_index(self):
+        """Test Page Rank calculation for an adjacency given as edge list."""
+        page_rank(edge_index=self.edge_index)
+
+    def test_page_rank_adj(self):
         """Test Page Rank calculation."""
-        api.page_rank(edge_index=self.edge_index)
+        page_rank(adj=self.adj)
 
-    def test_personalized_page_rank(self):
+    def test_personalized_page_rank_edge_index(self):
+        """Test Personalized Page Rank calculation for an adjacency given as edge list."""
+        personalized_page_rank(edge_index=self.edge_index)
+
+    def test_personalized_page_rank_adj(self):
         """Test Personalized Page Rank calculation."""
-        api.personalized_page_rank(edge_index=self.edge_index)
+        personalized_page_rank(adj=self.adj)
 
     def test_page_rank_manual(self):
         """Test Page Rank calculation on a simple manually created example."""
@@ -38,6 +47,6 @@ class APITest(unittest.TestCase):
         #     |
         #     D
         edge_index = torch.as_tensor(data=[(0, 1), (1, 2), (1, 3)]).t()
-        x = api.page_rank(edge_index=edge_index)
+        x = page_rank(edge_index=edge_index)
         # verify that central node has the largest PR value
         assert x.argmax() == 1
